Since idea function in ideation page getting heavy usage, the ux needs update for more explored scenarios.

New Function
1. I should able to drag file or folder into other folder
2. we shoud have an icon ">" on most right of the folder in folder tree.
		- when I click on > the idea preview section should be replaced with detailed folder view. I can do all the folder management in the view.
		- at the top bar of the folder view, show folder path, at most right, show list of actions I can do to the folder, such as add file, add folder, rename folder, delete folder etc.
		- in the content of the folder view. list all the files and folders in it, i should all actions avaiable to work with file, and sub folder and all files and sub folders in its sub folder.
3. on ideas folder tree, I should have a search bar beside pin. base on my type to filter out folder or files